@@ -185,7 +185,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             return self
         except Exception as e:
             LOGGER.error(e)
-            self.clean_up()
+            super().__exit__(exception_type=None, exception_value=None, traceback=None)
             raise
 
     @property
@@ -230,27 +230,25 @@ class NodeNetworkConfigurationPolicy(Resource):
             except Exception as e:
                 LOGGER.error(e)
 
-        super().clean_up()
+        self.delete()
 
     def wait_for_interface_deleted(self):
-        if self.worker_pods:
-            for pod in self.worker_pods:
-                for iface in self.ifaces:
-                    iface_name = iface["name"]
-                    node_network_state = NodeNetworkState(name=pod.node.name)
-                    iface_dict = node_network_state.get_interface(name=iface_name)
-                    if iface_dict.get("type") == "ethernet":
-                        LOGGER.info(f"{iface_name} is type ethernet, skipping.")
-                        continue
+        for pod in self.worker_pods:
+            for iface in self.ifaces:
+                iface_name = iface["name"]
+                node_network_state = NodeNetworkState(name=pod.node.name)
+                iface_dict = node_network_state.get_interface(name=iface_name)
+                if iface_dict.get("type") == "ethernet":
+                    LOGGER.info(f"{iface_name} is type ethernet, skipping.")
+                    continue
 
-                    node_network_state.wait_until_deleted(name=iface_name)
+                node_network_state.wait_until_deleted(name=iface_name)
 
     def validate_create(self):
-        if self.worker_pods:
-            for pod in self.worker_pods:
-                for bridge in self.ifaces:
-                    node_network_state = NodeNetworkState(name=pod.node.name)
-                    node_network_state.wait_until_up(name=bridge["name"])
+        for pod in self.worker_pods:
+            for bridge in self.ifaces:
+                node_network_state = NodeNetworkState(name=pod.node.name)
+                node_network_state.wait_until_up(name=bridge["name"])
 
     def _ipv4_state_backup(self):
         # Backup current state of dhcp for the interfaces which arent veth or current bridge
