@@ -3,7 +3,9 @@ import json
 import logging
 import os
 import re
+import sys
 from distutils.version import Version
+from signal import SIGINT, signal
 
 import kubernetes
 import urllib3
@@ -129,7 +131,7 @@ def _get_api_version(dyn_client, api_group, kind):
         LOGGER.warning(log)
         raise NotImplementedError(log)
 
-    LOGGER.info(f"Using api version: {res.group_version}")
+    LOGGER.info(f"kind: {kind} api version: {res.group_version}")
     return res.group_version
 
 
@@ -408,12 +410,27 @@ class Resource:
         return self._base_body()
 
     def __enter__(self):
+        signal(SIGINT, self._sigint_handler)
         return self.deploy()
 
     def __exit__(self, exception_type, exception_value, traceback):
+        # For debug, export kind (class name) + NOTEARDOWN to skip resource teardown.
+        # For example:export VirtualMachineInstanceNOTEARDOWN=True
+        skip_teardown_env = f"{self.kind}NOTEARDOWN"
+        no_teardown_from_environment = os.environ.get(skip_teardown_env)
+        if no_teardown_from_environment:
+            LOGGER.warning(
+                f"Skip teardown. Got {skip_teardown_env}={no_teardown_from_environment}"
+            )
+            return
+
         if self.teardown:
             self.clean_up()
 
+    def _sigint_handler(self, signal_received, frame):
+        self.__exit__(exception_type=None, exception_value=None, traceback=None)
+        sys.exit(signal_received)
+
     def deploy(self):
         self.create()
         return self
